DMCpy
============
Python software packaged designed for reduction of neutron powder diffraction data from DMC at PSI

## Installation
This package is to be install through the Python Package Manager by issuing 

```
pip install DMCpy
```



